@@ -11,15 +11,19 @@ class GeneralConfig:
     z_backlash: float
     travel_speed: float
     verbose: bool
+    macro_prefix: str | None
 
 
 @dataclass(frozen=True)
 class ScanConfig:
     samples: int
     models: dict[str, ScanModelConfiguration]
+    probe_speed: float
     mesh_runs: int
-    mesh_direction: Literal["x", "y"]
     mesh_height: float
+    mesh_corner_radius: float
+    mesh_direction: Literal["x", "y"]
+    mesh_path: Literal["snake", "alternating_snake", "spiral", "random"]
 
 
 @dataclass(frozen=True)
@@ -33,9 +37,10 @@ class TouchConfig:
 class BedMeshConfig:
     mesh_min: tuple[float, float]
     mesh_max: tuple[float, float]
-    mesh_points: tuple[int, int]
+    probe_count: tuple[int, int]
     speed: float
     horizontal_move_z: float
+    adaptive_margin: float
     zero_reference_position: tuple[float, float]
 
 
