@@ -19,7 +19,6 @@ logger = logging.getLogger(__name__)
 
 @final
 class TouchMacro(Macro):
-    name = "TOUCH"
     description = "Touch the bed to get the height offset at the current position."
     last_trigger_position: float | None = None
 
@@ -35,7 +34,6 @@ class TouchMacro(Macro):
 
 @final
 class TouchAccuracyMacro(Macro):
-    name = "TOUCH_ACCURACY"
     description = "Touch the bed multiple times to measure the accuracy of the probe."
 
     def __init__(self, probe: TouchMode, toolhead: Toolhead) -> None:
@@ -95,7 +93,6 @@ class TouchAccuracyMacro(Macro):
 
 @final
 class TouchHomeMacro(Macro):
-    name = "TOUCH_HOME"
     description = "Touch the bed to home Z axis"
 
     def __init__(
@@ -114,6 +111,18 @@ class TouchHomeMacro(Macro):
             msg = "Must home x and y before touch homing"
             raise RuntimeError(msg)
 
+        forced_z = False
+        if not self._toolhead.is_homed("z"):
+            forced_z = True
+            _, z_max = self._toolhead.get_z_axis_limits()
+            self._toolhead.set_z_position(z=z_max - 10)
+
+        pos = self._toolhead.get_position()
+        # TODO: Get rid of magic constants
+        self._toolhead.move(
+            z=pos.z + 2,
+            speed=5,
+        )
         self._toolhead.move(
             x=self._home_position[0],
             y=self._home_position[1],
@@ -121,12 +130,6 @@ class TouchHomeMacro(Macro):
         )
         self._toolhead.wait_moves()
 
-        forced_z = False
-        if not self._toolhead.is_homed("z"):
-            forced_z = True
-            _, z_max = self._toolhead.get_z_axis_limits()
-            self._toolhead.set_z_position(z=z_max - 10)
-
         try:
             trigger_pos = self._probe.perform_probe()
         finally:
@@ -134,11 +137,10 @@ class TouchHomeMacro(Macro):
                 self._toolhead.clear_z_homing_state()
 
         pos = self._toolhead.get_position()
-        self._toolhead.set_z_position(pos.z - (trigger_pos - self._probe.offset.z))
+        self._toolhead.set_z_position(pos.z - trigger_pos)
         logger.info(
-            "Touch home at (%.3f,%.3f) adjusted z by %.3f, offset %.3f",
+            "Touch home at (%.3f,%.3f) adjusted z by %.3f",
             pos.x,
             pos.y,
-            -trigger_pos,
-            -self._probe.offset.z,
+            trigger_pos,
         )
