@@ -6,10 +6,9 @@ from typing import TYPE_CHECKING
 import pytest
 from typing_extensions import TypeAlias
 
-from cartographer.interfaces.configuration import TouchModelConfiguration
 from cartographer.interfaces.printer import MacroParams, Position, Toolhead
 from cartographer.macros.touch import TouchAccuracyMacro, TouchHomeMacro, TouchMacro
-from cartographer.probe.touch_mode import TouchMode
+from cartographer.probe.touch_mode import TouchMode, TouchModeConfiguration
 
 if TYPE_CHECKING:
     from pytest import LogCaptureFixture
@@ -26,7 +25,7 @@ def offset() -> Position:
 @pytest.fixture
 def probe(mocker: MockerFixture, offset: Position) -> Probe:
     mock = mocker.Mock(spec=Probe, autospec=True)
-    mock.config = mocker.Mock(spec=TouchModelConfiguration, autospec=True)
+    mock.config = mocker.Mock(spec=TouchModeConfiguration, autospec=True)
     mock.config.move_speed = 42
     mock.offset = offset
     return mock
@@ -126,7 +125,10 @@ def test_touch_home_macro_moves(
 
     macro.run(params)
 
-    assert move_spy.mock_calls == [mocker.call(x=10, y=10, speed=mocker.ANY)]
+    assert move_spy.mock_calls == [
+        mocker.call(z=4, speed=mocker.ANY),
+        mocker.call(x=10, y=10, speed=mocker.ANY),
+    ]
 
 
 def test_touch_home_macro(
@@ -135,29 +137,18 @@ def test_touch_home_macro(
     toolhead: Toolhead,
     params: MacroParams,
 ):
+    # We are at 2, and touch the bed at -0.1.
+    height = 2
+    trigger = 0.1
+    # That means that the bed was further away than we thought,
+    # so we need to move the z axis "down".
+    expected = height - trigger
+
     macro = TouchHomeMacro(probe, toolhead, (10, 10))
-    probe.perform_probe = mocker.Mock(return_value=0.1)
-    toolhead.get_position = mocker.Mock(return_value=Position(0, 0, 2))
+    probe.perform_probe = mocker.Mock(return_value=trigger)
+    toolhead.get_position = mocker.Mock(return_value=Position(0, 0, height))
     set_z_position_spy = mocker.spy(toolhead, "set_z_position")
 
     macro.run(params)
 
-    assert set_z_position_spy.mock_calls == [mocker.call(1.9)]
-
-
-def test_touch_home_macro_with_z_offset(
-    mocker: MockerFixture,
-    probe: Probe,
-    offset: Position,
-    toolhead: Toolhead,
-    params: MacroParams,
-):
-    macro = TouchHomeMacro(probe, toolhead, (10, 10))
-    probe.perform_probe = mocker.Mock(return_value=0.0)
-    offset.z = -0.1
-    toolhead.get_position = mocker.Mock(return_value=Position(0, 0, 2))
-    set_z_position_spy = mocker.spy(toolhead, "set_z_position")
-
-    macro.run(params)
-
-    assert set_z_position_spy.mock_calls == [mocker.call(1.9)]
+    assert set_z_position_spy.mock_calls == [mocker.call(expected)]
